﻿Option Strict On
Imports System.IO.IsolatedStorage
Imports System.IO
Imports System.Xml.Linq

Partial Public Class haikuShow
    Inherits PhoneApplicationPage

    Public Sub New()
        InitializeComponent()
    End Sub

    Dim readSeason As String = String.Empty

    Protected Overrides Sub OnNavigatedTo(ByVal e As System.Windows.Navigation.NavigationEventArgs)
        Dim param As IDictionary(Of String, String) = NavigationContext.QueryString
        readSeason = param("Name")
        MyBase.OnNavigatedTo(e)
    End Sub

    Dim myFontSize As Integer = 25 '文字サイズ 
    Dim myLineHeight As Integer = 80 '行間 
    Dim edge As Integer = 80 '最終行と1行目の間のマージン 
    Dim myMargin, panoramaWidth As Integer

    '■この俳句表示ページがロードされた時の処理
    Private Sub haikuShow_Loaded(sender As Object, e As System.Windows.RoutedEventArgs) Handles MyBase.Loaded

        Canvas1.Children.Clear()

        forwardButton.Opacity = 0.3
        headButton.Opacity = 0.3
        backButton.Opacity = 0.3

        Dim itemDoc As XDocument
        Dim storage As IsolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication
        Dim filePath As String = Path.Combine("DailyHaikuData", readSeason & ".xml")

        If storage.FileExists(filePath) = True Then
            Dim myStream As IsolatedStorageFileStream = storage.OpenFile(filePath, FileMode.Open, FileAccess.Read)
            Dim reader As StreamReader = New StreamReader(myStream, System.Text.Encoding.UTF8)
            Dim readXmldoc As String = reader.ReadToEnd
            itemDoc = XDocument.Parse(readXmldoc)
            reader.Close()
            myStream.Close()

            Dim myDataQuery As IEnumerable(Of XElement) = From c In itemDoc.Descendants("句") Select c

            'スタイル設定 
            Dim myAllLines As Integer = 0
            myAllLines = myDataQuery.Count() '行数（句の数） 
            Dim myLine As Integer = 1 '行目 

            For Each myResult In myDataQuery
                '俳句が6句までで、1ページ内におさまる場合
                If myAllLines < 7 Then
                    myAllLines = 6
                End If

                Dim layoutLeft As Integer = (myAllLines - myLine) * myLineHeight '各行の左上隅までの左マージン 

                Dim myTextBlock As New TextBlock

                With myTextBlock
                    .Text = myResult.Value
                    .FontSize = myFontSize
                    .Width = myFontSize
                    .Height = 660
                    .TextWrapping = TextWrapping.Wrap
                    .Margin = New Thickness(layoutLeft, 0, 0, 0)
                    .Foreground = New SolidColorBrush(Colors.Black)
                    .IsHitTestVisible = False
                End With
                Canvas1.Children.Add(myTextBlock)
                myLine = myLine + 1
            Next

            panoramaWidth = myAllLines * myLineHeight + edge 'Panoramaの幅 
            Canvas1.Width = panoramaWidth

            myMargin = 480 - panoramaWidth + edge
            TextBlock1.Margin = New Thickness(myMargin, 0, 0, 0) 'd:DesignWidth="480" 

            '俳句が7句以上で、1ページ内におさまらない場合、行送りボタンを表示
            If myAllLines > 6 Then
                forwardButton.IsEnabled = True
                forwardButton.Opacity = 1
                headButton.IsEnabled = True
                headButton.Opacity = 1
                backButton.IsEnabled = True
                backButton.Opacity = 1
            End If
        Else
            Exit Sub
        End If
    End Sub

    '■「一句後へ」ボタンがタップされた時の処理
    Private Sub backButton_Tap(sender As System.Object, e As System.Windows.Input.GestureEventArgs) Handles backButton.Tap
        forwardButton.IsEnabled = True
        forwardButton.Opacity = 1
        headButton.IsEnabled = True
        headButton.Opacity = 1
        myMargin = myMargin + myLineHeight
        If myMargin > -edge Then
            TextBlock1.Margin = New Thickness(0, 0, 0, 0)
            backButton.IsEnabled = False
            backButton.Opacity = 0.3
        Else
            TextBlock1.Margin = New Thickness(myMargin, 0, 0, 0)
        End If
    End Sub

    '■「一句目へ」ボタンがタップされた時の処理
    Private Sub headButton_Tap(sender As System.Object, e As System.Windows.Input.GestureEventArgs) Handles headButton.Tap
        backButton.IsEnabled = True
        backButton.Opacity = 1
        forwardButton.IsEnabled = False
        forwardButton.Opacity = 0.3
        headButton.IsEnabled = False
        headButton.Opacity = 0.3
        myMargin = 480 - panoramaWidth + edge
        TextBlock1.Margin = New Thickness(myMargin, 0, 0, 0)
    End Sub

    '■「一句前へ」ボタンがタップされた時の処理
    Private Sub forwardButton_Tap(sender As System.Object, e As System.Windows.Input.GestureEventArgs) Handles forwardButton.Tap
        backButton.IsEnabled = True
        backButton.Opacity = 1
        myMargin = myMargin - myLineHeight
        If myMargin < 480 - panoramaWidth + edge + myLineHeight Then
            TextBlock1.Margin = New Thickness(480 - panoramaWidth + edge, 0, 0, 0)
            forwardButton.IsEnabled = False
            forwardButton.Opacity = 0.3
            headButton.IsEnabled = False
            headButton.Opacity = 0.3
        Else
            TextBlock1.Margin = New Thickness(myMargin, 0, 0, 0)
        End If
    End Sub

    '■「俳句入力」ボタンがタップされた時の処理
    Private Sub createHaikuPage_Tap(sender As System.Object, e As System.Windows.Input.GestureEventArgs) Handles createHaikuPage.Tap
        If Me.NavigationService.CanGoBack Then
            Me.NavigationService.GoBack()
        End If
    End Sub

    '■「季節選択」ボタンがタップされた時の処理
    Private Sub toMainPage_Tap(sender As System.Object, e As System.Windows.Input.GestureEventArgs) Handles toMainPage.Tap
        NavigationService.Navigate(New Uri("/MainPage.xaml?home=true", UriKind.Relative))
    End Sub

End Class
